@@ -1,7 +1,7 @@
 /* comport - PD external for unix/windows
 
  (c) 1998-2005  Winfried Ritsch (see LICENCE.txt)
- Institute for Electronic Music - Graz
+ iem -- Institute of Electronic Music - Graz
 
  V 1.0
 MP 20060603 memset and memcpy arguments were backwards for Windows version. close_serial doesn't crash now.
@@ -164,12 +164,12 @@ static long baudspeedbittable[] =
 */
 #else /* _WIN32 */
 
-#ifdef  IRIX
-#define OPENPARAMS (O_RDWR|O_NDELAY|O_NOCTTY)
-#define TIONREAD FIONREAD         /* re map the IOCTL function */
-#else /* IRIX */
-#define OPENPARAMS (O_RDWR|O_NDELAY|O_NOCTTY)
-#endif /* else IRIX */
+#ifdef  __sgi__
+# define OPENPARAMS (O_RDWR|O_NDELAY|O_NOCTTY)
+# define TIONREAD FIONREAD         /* re map the IOCTL function */
+#else /* __sgi__ */
+# define OPENPARAMS (O_RDWR|O_NDELAY|O_NOCTTY)
+#endif /* else __sgi__ */
 
 typedef struct baudbits_ {
   long rate;
@@ -366,7 +366,8 @@ allows COM port numbers to be specified. */
 #elif defined __linux__
     /* serial: ttyS?    USB-serial: ttyUSB?   USB-CDC: ttyACM? */
     static const char SERIAL_DEVICE_PREFIX[] = "/dev/tty[ASU]*";
-#elif defined IRIX
+#elif defined __sgi__
+    /* IRIX */
     static const char SERIAL_DEVICE_PREFIX[] = "/dev/ttyd*";
 #endif
 
@@ -851,13 +852,14 @@ static float set_stopflag(t_comport *x, t_float f_nr)
 static int set_ctsrts(t_comport *x, int nr)
 {
     struct termios *tio = &(x->com_termio);
-
+#ifdef CRTSCTS
     if(nr == 1)
     {
         tio->c_cflag |= CRTSCTS;
         return 1;
     }
     tio->c_cflag &= ~CRTSCTS;
+#endif
     return 0;
 }
 
@@ -1479,8 +1481,8 @@ static void *comport_new(t_symbol *s, int argc, t_atom *argv)
         memcpy(&(x->dcb), &(test.dcb), sizeof(DCB)); /*  for the new com config  */
 #else
         /* save the old com and new com config */
-        bcopy(&(test.oldcom_termio),&(x->oldcom_termio),sizeof(struct termios));
-        bcopy(&(test.com_termio),&(x->com_termio),sizeof(struct termios));
+        memcpy(&(x->oldcom_termio), &(test.oldcom_termio), sizeof(struct termios));
+        memcpy(&(x->com_termio)   , &(test.com_termio)   , sizeof(struct termios));
 #endif
     }
 
@@ -2052,7 +2054,11 @@ void comport_setup(void)
     null_tv.tv_sec = 0; /* no wait */
     null_tv.tv_usec = 0;
 #endif /* NOT _WIN32 */
-    logpost(0, PD_DEBUG, "comport - Pd external for unix/windows\n"
-        "LGPL-2.1+ 1998-2022,  Winfried Ritsch and others (see LICENSE.txt)\n"
-        "Institute for Electronic Music - Graz");
+    logpost(0, PD_DEBUG, "comport - access the serial port from within Pd\n"
+#ifdef VERSION
+        "    version  : " VERSION "\n"
+#endif
+        "    license  : LGPL-2.1+\n"
+        "    copyright: 1998-2024,  Winfried Ritsch and others (see LICENSE.txt)\n"
+        "               Institute of Electronic Music - Graz");
 }
